==> zither-1.1.11.tar.gz: zither_prj/apollon/block_delete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$BNAME = $_GET["BNAME"];
$BNAME2 = $_GET["BNAME2"];
$CNAME = $_GET["CNAME"];

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");

if(0 != strlen($BNAME) && 0 >= strlen($CNAME) && 0 >= strlen($BNAME2)){
   print("򤷤$BNAME ƻ֥åޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_data_delete.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<input type=submit value='ȿǤޤ'>";
   }
if(0 != strlen($BNAME) && 0 != strlen($CNAME) && 0 >= strlen($BNAME2)){
   print("򤷤$BNAME ƻ֥å򡢴ƻ륯饤 $CNAME ˰ưޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_data_copy.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<INPUT type='hidden' NAME=CNAME value=$CNAME>";
   echo "<input type=submit value='ȿǤޤ'>";
   }
if(0 != strlen($BNAME) && 0 != strlen($BNAME2) && 0 >= strlen($CNAME)){
   print("򤷤$BNAME ƻ֥å̾$BNAME2 ѹޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_name_mv.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<INPUT type='hidden' NAME=BNAME2 value=$BNAME2>";
   echo "<input type=submit value='ѹޤ'>";
   }
else{
   print("ƤʤᡢϽޤ\n");
   }

echo "\n";


print("</font>");

?>

</pre>
</body>
</html>

==> zither-1.1.16.tar.gz: zither_prj/apollon/block_delete.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$BNAME = enco($_GET["BNAME"]);
$BNAME2 = enco($_GET["BNAME2"]);
$CNAME = enco($_GET["CNAME"]);

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");

if(0 != strlen($BNAME) && 0 >= strlen($CNAME) && 0 >= strlen($BNAME2)){
   print("򤷤$BNAME ƻ֥åޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_data_delete.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<input type=submit value='ȿǤޤ'>";
   }
if(0 != strlen($BNAME) && 0 != strlen($CNAME) && 0 >= strlen($BNAME2)){
   print("򤷤$BNAME ƻ֥å򡢴ƻ륯饤 $CNAME ˰ưޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_data_copy.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<INPUT type='hidden' NAME=CNAME value=$CNAME>";
   echo "<input type=submit value='ȿǤޤ'>";
   }
if(0 != strlen($BNAME) && 0 != strlen($BNAME2) && 0 >= strlen($CNAME)){
   print("򤷤$BNAME ƻ֥å̾$BNAME2 ѹޤ\n");
   echo "\n";
   echo "<FORM METHOD=GET ACTION='block_name_mv.php' target='deletet'>";

   echo "<font color=red>";
   echo "Υܥ򲡤ȥǡ١ڤեȿǤޤ\n";
   echo "</font>";
   echo "\n";
   echo "<INPUT type='hidden' NAME=GEN value='taro'>";
   echo "<INPUT type='hidden' NAME=BNAME value=$BNAME>";
   echo "<INPUT type='hidden' NAME=BNAME2 value=$BNAME2>";
   echo "<input type=submit value='ѹޤ'>";
   }
else{
   print("ƤʤᡢϽޤ\n");
   }

echo "\n";


print("</font>");

?>

</pre>
</body>
</html>
